variable "allow_major_version_upgrade" {
  description = "Allow major engine version upgrades when changing engine versions"
  default     = true
}

variable "apply_immediately" {
  description = <<-EOT
    (Optional) Specifies whether any database modifications
    are applied immediately, or during the next maintenance
    window. Default is false. See Amazon RDS Documentation
    for more information.
  EOT
  default     = false
}

variable "env" {
  description = "Environment"
  default     = ""
}

variable "db_cluster_name" {
  description = "Custom cluster name"
  default     = ""
}

variable "port" {
}

variable "username" {
  default = "cbadmin"
}

variable "password" {
}

variable "engine_version" {
  description = "RDS Aurora PostgreSQL cluster engine version"
  default     = "9.6.16"
}

variable "enable_replicas" {
  default = false
}

variable "enable_failover" {
  default = true
}

variable "replica_count" {
  default = 1
}

variable "instance_type" {
  type = string
}

variable "subnet_ids" {
  default = []
  type    = list(string)
}

variable "security_group_ids" {
  default = []
  type    = list(string)
}

variable "cloudwatch_alarms_enabled" {
  default = false
}

variable "cloudwatch_memory_alarms_enabled" {
  default = false
}

variable "sns_enabled" {
  default = false
}

variable "backup_retention_period" {
  default = 7
}

variable "backup_window" {
  default = "04:35-05:05"
}

variable "replication_source_identifier" {
  default = ""
}

variable "aws_kms_key_bootstrap_arn" {
  default = ""
}

variable "aws_sns_topic_pd_low_arn" {
  default = ""
}

variable "aws_sns_topic_pd_high_arn" {
  default = ""
}

variable "pagerduty_high_endpoint" {
  default = ""
}

variable "pagerduty_low_endpoint" {
  default = ""
}

variable "database_name" {
}

variable "alert_thresholds" {
  type = map(string)
  default = {
    "aurora_cluster_free_memory" = "800000000"
    "aurora_replica_free_memory" = "800000000"
  }
}

variable "enable_performance_insights" {
  type        = bool
  description = "Enables Performance Insights RDS dashboard."
  default     = false
}

variable "deletion_protection" {
  type        = bool
  description = "Enables deletion protection for databse instance."
  default     = false
}

variable "cluster_tags" {
  description = "Custom tags for the aurora cluster resource"
  type        = map(string)
  default     = {}
}

variable "aurora_cluster_role_arns" {
  description = "IAM Role arns for aurora cluster to assume"
  type        = list(string)
  default     = []
}

variable "tags" {
  type        = map(string)
  description = "Tags for Aurora"
}

## --------------------------------------------------------
## parameter_groups.tf
## --------------------------------------------------------

variable "cluster_parameter_group_name" {
  description = "Name of parameter group to use for the 'aws_rds_cluster' resource."
  type        = string
  default     = null
}

variable "max_connections" {
  default = "1024"
}

variable "cluster_parameter_mapping" {
  description = "Map of cluster params to configure."
  type        = list(map(string))
  default     = null
}

variable "instance_parameter_group_name" {
  description = "Name of parameter group to use for the 'aws_rds_cluster_instance' resource."
  type        = string
  default     = null
}

variable "instance_parameter_mapping" {
  description = "Map of instance params to configure."
  type        = list(map(string))
  default     = null
}
